@@ -1,9 +1,11 @@
-// Copyright (C) 2008-2013 Conrad Sanderson
-// Copyright (C) 2008-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup unwrap
@@ -293,6 +295,26 @@ struct quasi_unwrap< Col<eT> >
 
 
 
+template<typename eT>
+struct quasi_unwrap< subview_row<eT> >
+  {
+  static const bool has_subview = false;
+  
+  inline
+  quasi_unwrap(const subview_row<eT>& A)
+    : M(A)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  const Row<eT> M;
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&M) == void_ptr(&X)); }
+  };
+
+
+
 template<typename eT>
 struct quasi_unwrap< subview_col<eT> >
   {
@@ -300,17 +322,17 @@ struct quasi_unwrap< subview_col<eT> >
   
   inline
   quasi_unwrap(const subview_col<eT>& A)
-    : M  ( const_cast<eT*>( A.colptr(0) ), A.n_rows, 1, false, false )
-    , src( A.m )
+    : orig( A.m )
+    , M  ( const_cast<eT*>( A.colptr(0) ), A.n_rows, false, false )
     {
     arma_extra_debug_sigprint();
     }
   
-  const Mat<eT>  M;
-  const Mat<eT>& src;
+  const Mat<eT>& orig;
+  const Col<eT>  M;
   
   template<typename eT2>
-  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&src) == void_ptr(&X)); }
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&orig) == void_ptr(&X)); }
   };
 
 
@@ -355,6 +377,30 @@ struct quasi_unwrap< mtOp<out_eT, T1, op_type> >
 
 
 
+template<typename T1>
+struct quasi_unwrap< Op<T1, op_vectorise_col> >
+  {
+  static const bool has_subview = true;
+  
+  typedef typename T1::elem_type eT;
+  
+  inline
+  quasi_unwrap(const Op<T1, op_vectorise_col>& A)
+    : U( A.m )
+    , M( const_cast<eT*>(U.M.memptr()), U.M.n_elem, 1, false, false )
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  const unwrap<T1> U;
+  const Mat<eT>    M;
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&(U.M)) == void_ptr(&X)); }
+  };
+
+
+
 //
 //
 //
@@ -463,6 +509,7 @@ struct unwrap_check< Mat<eT> >
     arma_extra_debug_sigprint();
     }
   
+  inline
   unwrap_check(const Mat<eT>& A, const bool is_alias)
     : M_local( is_alias ? new Mat<eT>(A) : 0 )
     , M      ( is_alias ? (*M_local)     : A )
@@ -499,6 +546,7 @@ struct unwrap_check< Row<eT> >
     arma_extra_debug_sigprint();
     }
   
+  inline
   unwrap_check(const Row<eT>& A, const bool is_alias)
     : M_local( is_alias ? new Row<eT>(A) : 0 )
     , M      ( is_alias ? (*M_local)     : A )
@@ -535,6 +583,7 @@ struct unwrap_check< Col<eT> >
     arma_extra_debug_sigprint();
     }
   
+  inline
   unwrap_check(const Col<eT>& A, const bool is_alias)
     : M_local( is_alias ? new Col<eT>(A) : 0 )
     , M      ( is_alias ? (*M_local)     : A )
@@ -721,7 +770,9 @@ struct partial_unwrap_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -743,7 +794,9 @@ struct partial_unwrap_fixed
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -786,7 +839,9 @@ struct partial_unwrap< Mat<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return ((&X) == (&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -808,7 +863,9 @@ struct partial_unwrap< Row<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -830,7 +887,9 @@ struct partial_unwrap< Col<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -840,8 +899,6 @@ struct partial_unwrap< Col<eT> >
 
 
 
-// NOTE: we can get away with this shortcut as the partial_unwrap class is only used by as_scalar(),
-// NOTE: which doesn't need to check for aliasing (ie. it doesn't need to compare the address of M with another matrix)
 template<typename eT>
 struct partial_unwrap< subview_col<eT> >
   {
@@ -849,17 +906,45 @@ struct partial_unwrap< subview_col<eT> >
   
   inline
   partial_unwrap(const subview_col<eT>& A)
-    : M  ( const_cast<eT*>( A.colptr(0) ), A.n_rows, false, false )
+    : orig( A.m )
+    , M   ( const_cast<eT*>( A.colptr(0) ), A.n_rows, false, false )
     {
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
   
-  const Col<eT> M;
+  const Mat<eT>& orig;
+  const Col<eT>  M;
+  };
+
+
+
+template<typename eT>
+struct partial_unwrap< subview_row<eT> >
+  {
+  typedef Row<eT> stored_type;
+  
+  inline
+  partial_unwrap(const subview_row<eT>& A)
+    : M(A)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
+  const Row<eT> M;
   };
 
 
@@ -877,7 +962,9 @@ struct partial_unwrap_htrans_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -899,7 +986,9 @@ struct partial_unwrap_htrans_fixed
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -943,6 +1032,8 @@ struct partial_unwrap< Op< Mat<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = false;
   
@@ -965,6 +1056,8 @@ struct partial_unwrap< Op< Row<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = false;
   
@@ -987,6 +1080,8 @@ struct partial_unwrap< Op< Col<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = false;
   
@@ -995,8 +1090,6 @@ struct partial_unwrap< Op< Col<eT>, op_htrans> >
 
 
 
-// NOTE: we can get away with this shortcut as the partial_unwrap class is only used by as_scalar(),
-// NOTE: which doesn't need to check for aliasing (ie. it doesn't need to compare the address of M with another matrix)
 template<typename eT>
 struct partial_unwrap< Op< subview_col<eT>, op_htrans> >
   {
@@ -1004,17 +1097,45 @@ struct partial_unwrap< Op< subview_col<eT>, op_htrans> >
   
   inline
   partial_unwrap(const Op< subview_col<eT>, op_htrans>& A)
-    : M  ( const_cast<eT*>( A.m.colptr(0) ), A.m.n_rows, false, false )
+    : orig( A.m.m )
+    , M   ( const_cast<eT*>( A.m.colptr(0) ), A.m.n_rows, false, false )
     {
     arma_extra_debug_sigprint();
     }
   
   arma_inline eT get_val() const { return eT(1); }
   
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  
   static const bool do_trans = true;
   static const bool do_times = false;
   
-  const Col<eT> M;
+  const Mat<eT>& orig;
+  const Col<eT>  M;
+  };
+
+
+
+template<typename eT>
+struct partial_unwrap< Op< subview_row<eT>, op_htrans> >
+  {
+  typedef Row<eT> stored_type;
+  
+  inline
+  partial_unwrap(const Op< subview_row<eT>, op_htrans>& A)
+    : M(A.m)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline eT get_val() const { return eT(1); }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
+  const Row<eT> M;
   };
 
 
@@ -1035,6 +1156,8 @@ struct partial_unwrap_htrans2_default
   
   arma_inline eT get_val() const { return val; }
   
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  
   static const bool do_trans = true;
   static const bool do_times = true;
   
@@ -1059,6 +1182,8 @@ struct partial_unwrap_htrans2_fixed
   
   arma_inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = true;
   
@@ -1103,6 +1228,8 @@ struct partial_unwrap< Op< Mat<eT>, op_htrans2> >
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = true;
   
@@ -1127,6 +1254,8 @@ struct partial_unwrap< Op< Row<eT>, op_htrans2> >
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = true;
   
@@ -1151,6 +1280,8 @@ struct partial_unwrap< Op< Col<eT>, op_htrans2> >
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = true;
   static const bool do_times = true;
   
@@ -1160,8 +1291,6 @@ struct partial_unwrap< Op< Col<eT>, op_htrans2> >
 
 
 
-// NOTE: we can get away with this shortcut as the partial_unwrap class is only used by as_scalar(),
-// NOTE: which doesn't need to check for aliasing (ie. it doesn't need to compare the address of M with another matrix)
 template<typename eT>
 struct partial_unwrap< Op< subview_col<eT>, op_htrans2> >
   {
@@ -1169,19 +1298,50 @@ struct partial_unwrap< Op< subview_col<eT>, op_htrans2> >
   
   inline
   partial_unwrap(const Op< subview_col<eT>, op_htrans2>& A)
-    : val( A.aux )
-    , M  ( const_cast<eT*>( A.m.colptr(0) ), A.m.n_rows, false, false )
+    : orig( A.m.m )
+    , val ( A.aux )
+    , M   ( const_cast<eT*>( A.m.colptr(0) ), A.m.n_rows, false, false )
     {
     arma_extra_debug_sigprint();
     }
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
+  const Mat<eT>& orig;
+  
+  const eT      val;
+  const Col<eT> M;
+  };
+
+
+
+template<typename eT>
+struct partial_unwrap< Op< subview_row<eT>, op_htrans2> >
+  {
+  typedef Row<eT> stored_type;
+  
+  inline
+  partial_unwrap(const Op< subview_row<eT>, op_htrans2>& A)
+    : val(A.aux)
+    , M  (A.m  )
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline eT get_val() const { return val; }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  
   static const bool do_trans = true;
   static const bool do_times = true;
   
   const eT      val;
-  const Col<eT> M;
+  const Row<eT> M;
   };
 
 
@@ -1200,7 +1360,9 @@ struct partial_unwrap_scalar_times_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return val; }
+  arma_inline eT get_val() const { return val; }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1227,6 +1389,8 @@ struct partial_unwrap_scalar_times_fixed
   
   arma_hot arma_inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = false;
   static const bool do_times = true;
   
@@ -1275,6 +1439,8 @@ struct partial_unwrap< eOp<Mat<eT>, eop_scalar_times> >
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = false;
   static const bool do_times = true;
   
@@ -1299,6 +1465,8 @@ struct partial_unwrap< eOp<Row<eT>, eop_scalar_times> >
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = false;
   static const bool do_times = true;
   
@@ -1323,6 +1491,8 @@ struct partial_unwrap< eOp<Col<eT>, eop_scalar_times> >
   
   inline eT get_val() const { return val; }
   
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  
   static const bool do_trans = false;
   static const bool do_times = true;
   
@@ -1332,7 +1502,58 @@ struct partial_unwrap< eOp<Col<eT>, eop_scalar_times> >
 
 
 
-// TODO: struct partial_unwrap< eOp<subview_col<eT>, eop_scalar_times> >
+template<typename eT>
+struct partial_unwrap< eOp<subview_col<eT>, eop_scalar_times> >
+  {
+  typedef Col<eT> stored_type;
+  
+  arma_hot inline
+  partial_unwrap(const eOp<subview_col<eT>,eop_scalar_times>& A)
+    : orig( A.P.Q.m )
+    , val ( A.aux   )
+    , M   ( const_cast<eT*>( A.P.Q.colptr(0) ), A.P.Q.n_rows, false, false )
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_hot arma_inline eT get_val() const { return val; }
+  
+  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
+  const Mat<eT>& orig;
+  
+  const eT      val;
+  const Col<eT> M;
+  };
+
+
+
+template<typename eT>
+struct partial_unwrap< eOp<subview_row<eT>, eop_scalar_times> >
+  {
+  typedef Row<eT> stored_type;
+  
+  arma_hot inline
+  partial_unwrap(const eOp<subview_row<eT>,eop_scalar_times>& A)
+    : val(A.aux)
+    , M  (A.P.Q)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline eT get_val() const { return val; }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
+  const eT      val;
+  const Row<eT> M;
+  };
 
 
 
@@ -1349,7 +1570,9 @@ struct partial_unwrap_neg_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1372,7 +1595,9 @@ struct partial_unwrap_neg_fixed
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1418,7 +1643,9 @@ struct partial_unwrap< eOp<Mat<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1440,7 +1667,9 @@ struct partial_unwrap< eOp<Row<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1462,7 +1691,9 @@ struct partial_unwrap< eOp<Col<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1472,7 +1703,53 @@ struct partial_unwrap< eOp<Col<eT>, eop_neg> >
 
 
 
-// TODO: struct partial_unwrap< eOp<subview_col<eT>, eop_neg> >
+template<typename eT>
+struct partial_unwrap< eOp<subview_col<eT>, eop_neg> >
+  {
+  typedef Col<eT> stored_type;
+  
+  inline
+  partial_unwrap(const eOp<subview_col<eT>,eop_neg>& A)
+    : orig( A.P.Q.m )
+    , M   ( const_cast<eT*>( A.P.Q.colptr(0) ), A.P.Q.n_rows, false, false )
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
+  const Mat<eT>& orig;
+  const Col<eT>  M;
+  };
+
+
+
+template<typename eT>
+struct partial_unwrap< eOp<subview_row<eT>, eop_neg> >
+  {
+  typedef Row<eT> stored_type;
+  
+  inline
+  partial_unwrap(const eOp<subview_row<eT>,eop_neg>& A)
+    : M(A.P.Q)
+    {
+    arma_extra_debug_sigprint();
+    }
+  
+  arma_inline eT get_val() const { return eT(-1); }
+  
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
+  const Row<eT> M;
+  };
 
 
 
@@ -1493,7 +1770,7 @@ struct partial_unwrap_check_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1524,7 +1801,7 @@ struct partial_unwrap_check_fixed
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1579,7 +1856,7 @@ struct partial_unwrap_check< Mat<eT> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1613,7 +1890,7 @@ struct partial_unwrap_check< Row<eT> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1647,7 +1924,7 @@ struct partial_unwrap_check< Col<eT> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1673,7 +1950,7 @@ struct partial_unwrap_check< subview_col<eT> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1696,7 +1973,7 @@ struct partial_unwrap_check_htrans_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1727,7 +2004,7 @@ struct partial_unwrap_check_htrans_fixed
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1782,7 +2059,7 @@ struct partial_unwrap_check< Op< Mat<eT>, op_htrans> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1815,7 +2092,7 @@ struct partial_unwrap_check< Op< Row<eT>, op_htrans> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1848,7 +2125,7 @@ struct partial_unwrap_check< Op< Col<eT>, op_htrans> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1874,7 +2151,7 @@ struct partial_unwrap_check< Op< subview_col<eT>, op_htrans> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -2322,7 +2599,7 @@ struct partial_unwrap_check_neg_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2354,7 +2631,7 @@ struct partial_unwrap_check_neg_fixed
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2409,7 +2686,7 @@ struct partial_unwrap_check< eOp<Mat<eT>, eop_neg> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2441,7 +2718,7 @@ struct partial_unwrap_check< eOp<Row<eT>, eop_neg> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2473,7 +2750,7 @@ struct partial_unwrap_check< eOp<Col<eT>, eop_neg> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2498,7 +2775,7 @@ struct partial_unwrap_check< eOp<subview_col<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
